.. include:: ../README.rst
   :end-before: About

.. include:: ../README.rst
   :start-after: -----
   :end-before: Features

.. toctree::
   :numbered:

   introduction
   api
   configuration
   contributing
   changes
   license
   authors
